library platform_list_tile;

export 'src/material_list_tile.dart';

import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:cupertino_list_tile/cupertino_list_tile.dart';
import 'dart:io';
import 'src/material_list_tile.dart';

/// This is the PlatFormListTile class. It combines the Material and Cupertino Versions of the ListTile.

class PlatformListTile extends StatelessWidget {
  PlatformListTile({
    this.leading,
    this.title,
    this.subtitle,
    this.trailing,
    this.isThreeLine = false,
    this.dense,
    this.contentPadding,
    this.enabled = true,
    this.onTap,
    this.onLongPress,
    this.selected = false,
    this.focusColor,
    this.hoverColor,
    this.focusNode,
    this.autofocus = false,
    this.tileColorM,
    this.selectedTileColorM,
    this.enableFeedbackM,
    this.horizontalTitleGapM,
    this.minVerticalPaddingM,
    this.minLeadingWidthM,
    this.isElevatedM = false,
    this.shapeM,
    this.visualDensityM,
    this.elevationM = 6.0,
  });

  final Widget? leading;
  final Widget? title;
  final Widget? subtitle;
  final Widget? trailing;
  final bool isElevatedM;
  final bool enabled;
  final bool isThreeLine;
  final bool? dense;
  final EdgeInsetsGeometry? contentPadding;
  final GestureTapCallback? onTap;
  final GestureLongPressCallback? onLongPress;
  final bool selected;
  final Color? focusColor;
  final Color? hoverColor;
  final FocusNode? focusNode;
  final bool autofocus;
  final Color? tileColorM;
  final Color? selectedTileColorM;
  final bool? enableFeedbackM;
  final double? horizontalTitleGapM;
  final double? minVerticalPaddingM;
  final double? minLeadingWidthM;
  final ShapeBorder? shapeM;
  final VisualDensity? visualDensityM;
  final double elevationM;

  @override
  Widget build(BuildContext context) {
    if (Platform.isIOS) {
      return CupertinoListTile(
        isThreeLine: isThreeLine,
        dense: dense,
        contentPadding: contentPadding,
        onTap: onTap,
        onLongPress: onLongPress,
        selected: selected,
        focusColor: focusColor,
        hoverColor: hoverColor,
        focusNode: focusNode,
        autofocus: autofocus,
        enabled: enabled,
        leading: leading,
        title: title,
        subtitle: subtitle,
        trailing: trailing,
      );
    } else if (isElevatedM) {
      return Card(
        elevation: elevationM,
        child: MaterialListTile(
          title: title,
          leading: leading,
          subtitle: subtitle,
          trailing: trailing,
          enabled: enabled,
          isThreeLine: isThreeLine,
          dense: dense,
          contentPadding: contentPadding,
          onTap: onTap,
          onLongPress: onLongPress,
          selected: selected,
          focusColor: focusColor,
          hoverColor: hoverColor,
          focusNode: focusNode,
          autofocus: autofocus,
          tileColor: tileColorM,
          selectedTileColor: selectedTileColorM,
          enableFeedback: enableFeedbackM,
          horizontalTitleGap: horizontalTitleGapM,
          minVerticalPadding: minVerticalPaddingM,
          minLeadingWidth: minLeadingWidthM,
          shape: shapeM,
          visualDensity: visualDensityM,
        ),
      );
    } else {
      return MaterialListTile(
        title: title,
        leading: leading,
        subtitle: subtitle,
        trailing: trailing,
        enabled: enabled,
        isThreeLine: isThreeLine,
        dense: dense,
        contentPadding: contentPadding,
        onTap: onTap,
        onLongPress: onLongPress,
        selected: selected,
        focusColor: focusColor,
        hoverColor: hoverColor,
        focusNode: focusNode,
        autofocus: autofocus,
        tileColor: tileColorM,
        selectedTileColor: selectedTileColorM,
        enableFeedback: enableFeedbackM,
        horizontalTitleGap: horizontalTitleGapM,
        minVerticalPadding: minVerticalPaddingM,
        minLeadingWidth: minLeadingWidthM,
        shape: shapeM,
        visualDensity: visualDensityM,
      );
    }
  }
}
